@@ -35,8 +35,8 @@ return [
 		['name' => 'settings#getConfig', 'url' => '/v1/config', 'verb' => 'GET'],
 		['name' => 'settings#setConfig', 'url' => '/v1/config', 'verb' => 'POST'],
 		//Autocompletion
-		['name' => 'contact#searchAttendee', 'url' => '/v1/autocompletion/attendee', 'verb' => 'GET'],
-		['name' => 'contact#searchLocation', 'url' => '/v1/autocompletion/location', 'verb' => 'GET'],
+		['name' => 'contact#searchAttendee', 'url' => '/v1/autocompletion/attendee', 'verb' => 'POST'],
+		['name' => 'contact#searchLocation', 'url' => '/v1/autocompletion/location', 'verb' => 'POST'],
 
 		['name' => 'proxy#proxy', 'url' => '/v1/proxy', 'verb' => 'GET'],
 	]
