@@ -62,7 +62,7 @@ OC.L10N.register(
     "2 hours before" : "2 hodiny předem",
     "Custom" : "Vlastní",
     "Audio" : "Audio",
-    "Email" : "Email",
+    "Email" : "E-mail",
     "Pop-up" : "Vyskakovací",
     "sec" : "sek",
     "min" : "min",
@@ -117,7 +117,7 @@ OC.L10N.register(
     "can edit" : "lze upravovat",
     "Share link" : "Sdílet odkaz",
     "Public access" : "Veřejný přístup",
-    "Email link to person" : "Odeslat odkaz emailem",
+    "Email link to person" : "Odeslat odkaz e-mailem",
     "Send" : "Odeslat",
     "New Calendar" : "Nový kalendář",
     "Name" : "Název",
@@ -136,8 +136,8 @@ OC.L10N.register(
     "Repeat" : "Opakovat",
     "times every" : "krát každých",
     "Add" : "Přidat",
-    "Email address of attendee" : "Emailová adresa účastníka",
-    "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou emailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
+    "Email address of attendee" : "E-mailová adresa účastníka",
+    "Please add your email address in the personal settings in order to add attendees." : "Zadejte prosím svou e-mailovou adresu v osobním nastavení, abyste mohli přidávat účastníky.",
     "from" : "od",
     "to" : "do",
     "This event's repeating rule is not supported yet." : "Pravidlo opakování této události není ještě podporováno.",
@@ -158,10 +158,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe k integraci",
     "Publish URL" : "Zveřejnit URL",
     "Settings & import" : "Nastavení & import",
-    "Skip simple event editor" : "Přeskočit jednoduchý editor události",
-    "Show week numbers" : "Zobrazit čísla týdnů",
     "Import calendar" : "Importovat kalendář",
     "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
+    "Skip simple event editor" : "Přeskočit jednoduchý editor události",
+    "Show week numbers" : "Zobrazit čísla týdnů",
     "Primary CalDAV address" : "Primární adresa CalDAV",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa",
     "Subscribe" : "Odebírat"
