@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Some events in this calendar are broken. Please check the JS console for more info.",
     "Share Calendar" : "Share Calendar",
     "Shared" : "Shared",
+    "Could not save WebCal-calendar" : "Could not save WebCal-calendar",
     "WebDAV address for subscriptions" : "WebDAV address for subscription",
+    "Email sent." : "Email sent.",
+    "Could not send your email." : "Could not send your email.",
     "group" : "group",
     "Details" : "Details",
     "Attendees" : "Attendees",
@@ -193,10 +196,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe to integrate",
     "Publish URL" : "Publish URL",
     "Settings & import" : "Settings & import",
-    "Skip simple event editor" : "Skip simple event editor",
-    "Show week numbers" : "Show week numbers",
     "Import calendar" : "Import calendar",
     "No Calendars selected for import" : "No Calendars selected for import",
+    "Skip simple event editor" : "Skip simple event editor",
+    "Show week numbers" : "Show week numbers",
     "Primary CalDAV address" : "Primary CalDAV address",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV address",
     "Subscribe" : "Subscribe"
