@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
     "Share Calendar" : "Compartir calendario",
     "Shared" : "Compartido",
+    "Could not save WebCal-calendar" : "No se ha podido guardar el calendario WebCal",
     "WebDAV address for subscriptions" : "Dirección WebDAV para los subscriptores",
+    "Email sent." : "Correo enviado.",
+    "Could not send your email." : "No se ha podido enviar tu correo.",
     "group" : "grupo",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
@@ -193,10 +196,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe para integrar",
     "Publish URL" : "Publicar URL",
     "Settings & import" : "Ajustes & importar",
-    "Skip simple event editor" : "Omitir el editor de evento único",
-    "Show week numbers" : "Mostrar numero de semana",
     "Import calendar" : "Importar calendario",
     "No Calendars selected for import" : "No se seleccionó un calendario para importar",
+    "Skip simple event editor" : "Omitir el editor de evento único",
+    "Show week numbers" : "Mostrar numero de semana",
     "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
     "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX",
     "Subscribe" : "Suscribirse"
