@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Jotkin tapahtumat tässä kalenterisas ovat rikki. Tarkista JS-konsoli saadaksesi lisätietoja.",
     "Share Calendar" : "Jaa kalenteri",
     "Shared" : "Jaettu",
+    "Could not save WebCal-calendar" : "Ei voitu tallentaa WebCal-kalenteria",
     "WebDAV address for subscriptions" : "WebDAV-osoite tilauksille",
+    "Email sent." : "Sähköposti lähetetty.",
+    "Could not send your email." : "Sähköpostiviestiäsi ei voitu lähettää.",
     "group" : "ryhmä",
     "Details" : "Tiedot",
     "Attendees" : "Osallistujat",
@@ -193,10 +196,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Integroitava iframe",
     "Publish URL" : "Julkaise URL",
     "Settings & import" : "Asetukset ja tuonti",
-    "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
-    "Show week numbers" : "Näytä viikkonumerot",
     "Import calendar" : "Tuo kalenteri",
     "No Calendars selected for import" : "Kalentereita ei ole valittu tuotavaksi",
+    "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
+    "Show week numbers" : "Näytä viikkonumerot",
     "Primary CalDAV address" : "Ensisijainen CalDAV-osoite",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV -osoite",
     "Subscribe" : "Tilaa"
