@@ -4,10 +4,14 @@ OC.L10N.register(
     "Calendar" : "Օրացույց",
     "Individual" : "Անհատ",
     "Group" : "Խումբ",
+    "Resource" : "Ռեսուրս",
     "Room" : "Սենյակ",
     "Unknown" : "Անհայտ",
-    "New event" : "Նոր դեպք",
+    "New event" : "Նոր իրադարձություն",
+    "Share Calendar" : "Կիսվել օրացույցով",
+    "Shared" : "Կիսված",
     "group" : "խումբ",
+    "Details" : "Մանրամասներ",
     "Attendees" : "Մասնակիցներ",
     "Reminders" : "Հիշեցումներ",
     "Repeating" : "Կրկնվող",
@@ -26,11 +30,13 @@ OC.L10N.register(
     "30 minutes before" : "30 րոպե առաջ",
     "1 hour before" : "1 ժամ առաջ",
     "2 hours before" : "2 ժամ առաջ",
+    "Email" : "Էլ․փոստ",
     "sec" : "վրկ",
     "min" : "րոպե",
     "hours" : "ժամ",
     "days" : "օր",
     "week" : "շաբաթ",
+    "before" : "առաջ",
     "start" : "սկիզբ",
     "end" : "վերջ",
     "{type} {time} before the event starts" : "{type} {time} մինչ միջոցառման սկիզբը",
@@ -57,8 +63,6 @@ OC.L10N.register(
     "Week" : "Շաբաթ",
     "Month" : "Ամիս",
     "Today" : "Այսօր",
-    "Share Calendar" : "Կիսվել օրացույցով",
-    "Shared" : "Կիսված",
     "More" : "Ավելի",
     "Edit" : "Խմբագրել",
     "Link" : "Հղում",
