@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Sumir atburðir í þessu dagatali eru gallaðir. Athugaðu JS-stjórnborðið til að sjá frekari upplýsingar.",
     "Share Calendar" : "Deila dagatali",
     "Shared" : "Deilt",
+    "Could not save WebCal-calendar" : "Gat ekki vistað WebCal-dagatal",
     "WebDAV address for subscriptions" : "WebDAV-vistfang fyrir áskriftir",
+    "Email sent." : "Sendi tölvupóst.",
+    "Could not send your email." : "Gat ekki sent tölvupóstinn.",
     "group" : "hópur",
     "Details" : "Nánar",
     "Attendees" : "Þáttakendur",
@@ -74,12 +77,46 @@ OC.L10N.register(
     "end" : "endir",
     "Editing reminders of unknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
     "Week {number} of {year}" : "Vika {number},{year}",
+    "Successfully imported {imported} objects" : "Tókst að flytja inn {imported} hluti",
+    "Imported {imported} out of {all}, skipped one duplicate" : "Flutti inn {imported} af {all}, sleppti einu tvítaki",
+    "Imported {imported} out of {all}, one failure" : "Flutti inn {imported} af {all}, eitt mistókst",
+    "Imported {imported} out of {all}, {errors} failures" : "Flutti inn {imported} af {all}, {errors} mistókust",
+    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Flutti inn {imported} af {all}, sleppti {duplicates} tvítökum",
+    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Flutti inn {imported} af {all}, {errors} mistókust, sleppti {duplicates} tvítökum",
+    "Audio alarm {time} before the event starts" : "Hljóðáminning {time} áður en atburður hefst",
+    "Pop-up {time} before the event starts" : "Sprettgluggi {time} áður en atburður hefst",
+    "Email {time} before the event starts" : "Tölvupóstur {time} áður en atburður hefst",
+    "None {time} before the event starts" : "Ekkert {time} áður en atburður hefst",
     "{type} {time} before the event starts" : "{type} {time} áður en atburður hefst",
+    "Audio alarm {time} before the event ends" : "Hljóðáminning {time} áður en atburður endar",
+    "Pop-up {time} before the event ends" : "Sprettgluggi {time} áður en atburður endar",
+    "Email {time} before the event ends" : "Tölvupóstur {time} áður en atburður endar",
+    "None {time} before the event ends" : "Ekkert {time} áður en atburður endar",
     "{type} {time} before the event ends" : "{type} {time} áður en atburður endar",
+    "Audio alarm {time} after the event starts" : "Hljóðáminning {time} eftir að atburður hefst",
+    "Pop-up {time} after the event starts" : "Sprettgluggi {time} eftir að atburður hefst",
+    "Email {time} after the event starts" : "Tölvupóstur {time} eftir að atburður hefst",
+    "None {time} after the event starts" : "Ekkert {time} eftir að atburður hefst",
     "{type} {time} after the event starts" : "{type} {time} eftir að atburður hefst",
+    "Audio alarm {time} after the event ends" : "Hljóðáminning {time} eftir að atburður endar",
+    "Pop-up {time} after the event ends" : "Sprettgluggi {time} eftir að atburður endar",
+    "Email {time} after the event ends" : "Tölvupóstur {time} eftir að atburður endar",
+    "None {time} after the event ends" : "Ekkert {time} eftir að atburður endar",
     "{type} {time} after the event ends" : "{type} {time} eftir að atburður endar",
+    "Audio alarm at the event's start" : "Hljóðáminning við upphafstíma atburðar",
+    "Pop-up at the event's start" : "Sprettgluggi við upphafstíma atburðar",
+    "Email at the event's start" : "Tölvupóstur við upphafstíma atburðar",
+    "None at the event's start" : "Ekkert við upphafstíma atburðar",
     "{type} at the event's start" : "{type} við upphafstíma atburðar",
+    "Audio alarm at the event's end" : "Hljóðáminning við lok atburðar",
+    "Pop-up at the event's end" : "Sprettgluggi við lok atburðar",
+    "Email at the event's end" : "Tölvupóstur við lok atburðar",
+    "None at the event's end" : "Ekkert við lok atburðar",
     "{type} at the event's end" : "{type} við endatíma atburðar",
+    "Audio alarm at {time}" : "Hljóðáminning kl. {time}",
+    "Pop-up at {time}" : "Sprettgluggi kl. {time}",
+    "Email at {time}" : "Tölvupóstur kl. {time}",
+    "None at {time}" : "Ekkert kl. {time}",
     "{type} at {time}" : "{type} klukkan {time}",
     "{calendar} shared by {owner}" : "{calendar} deilt af {owner}",
     "Please enter a valid WebCal-URL" : "Skráðu inn gilda WebCal-slóð",
@@ -135,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Algilt",
     "Repeat" : "Endurtaka",
     "times every" : "sinnum hverjar",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Ekki er enn búið að setja tölvupóstáminningar í CalDAV-þjóninn, þannig að enginn tölvupóstur verður sendur.",
     "Add" : "Bæta við",
     "Email address of attendee" : "Tölvupóstfang þátttakanda",
     "Please add your email address in the personal settings in order to add attendees." : "Settu inn tölvupóstfangið þitt í einkastillingum þínum svo að þú getir bætt við þátttakendum.",
@@ -158,10 +196,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe-rammi til að samþætta",
     "Publish URL" : "Gefa út slóð",
     "Settings & import" : "Stillingar og innflutningur",
-    "Skip simple event editor" : "Sleppa einföldum atburðaritli",
-    "Show week numbers" : "Sýna vikunúmer",
     "Import calendar" : "Flytja inn dagatal",
     "No Calendars selected for import" : "Engin dagatöl valin til innflutnings",
+    "Skip simple event editor" : "Sleppa einföldum atburðaritli",
+    "Show week numbers" : "Sýna vikunúmer",
     "Primary CalDAV address" : "Aðal-CalDAV-vistfang",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-vistfang",
     "Subscribe" : "Gerast áskrifandi"
