@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Sommige afspraken in de agenda zijn kapot. Controleer de JS console voor meer info.",
     "Share Calendar" : "Delen agenda",
     "Shared" : "Gedeeld",
+    "Could not save WebCal-calendar" : "Kon WebCal agenda niet opslaan",
     "WebDAV address for subscriptions" : "WebDAV adres voor abonnementen",
+    "Email sent." : "E-mail verzonden.",
+    "Could not send your email." : "Kon je e-mail niet versturen.",
     "group" : "groep",
     "Details" : "Details",
     "Attendees" : "Deelnemers",
@@ -193,10 +196,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe integreert",
     "Publish URL" : "Publiceren URL",
     "Settings & import" : "Instellingen & importeren",
-    "Skip simple event editor" : "Negeer simpele afsprakenbewerker",
-    "Show week numbers" : "Tonen weeknummers",
     "Import calendar" : "Importeer agenda",
     "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
+    "Skip simple event editor" : "Negeer simpele afsprakenbewerker",
+    "Show week numbers" : "Tonen weeknummers",
     "Primary CalDAV address" : "Primair CalDAV adres",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adres",
     "Subscribe" : "Abonneren"
