@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Niektóre zdarzenia w tym kalendarzu są uszkodzone. Proszę sprawdzić konsole JS, aby dowiedzieć się więcej.",
     "Share Calendar" : "Współdziel kalendarz",
     "Shared" : "Udostępniono",
+    "Could not save WebCal-calendar" : "Błąd podczas zapisywania kalendarza WebCal",
     "WebDAV address for subscriptions" : "Adres WebDAV dla subskrypcji",
+    "Email sent." : "E-mail wysłany.",
+    "Could not send your email." : "Nie udało się wysłać Twojego e-maila.",
     "group" : "grupa",
     "Details" : "Szczegóły",
     "Attendees" : "Uczestnicy",
@@ -169,6 +172,7 @@ OC.L10N.register(
     "Absolute" : "Całkowity",
     "Repeat" : "Powtarzaj",
     "times every" : "razy w każdy",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Przypomnienia e-mail nie zostały zaimplementowane w CalDAV, dlatego żadne z nich nie będą wysyłane.",
     "Add" : "Dodaj",
     "Email address of attendee" : "Adres e-mail uczestnika",
     "Please add your email address in the personal settings in order to add attendees." : "Aby dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
@@ -192,10 +196,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe do osadzenia",
     "Publish URL" : "Publikowanie URL",
     "Settings & import" : "Ustawienia i import",
-    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
-    "Show week numbers" : "Pokaż numery tygodni",
     "Import calendar" : "Importuj kalendarz",
     "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
+    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
+    "Show week numbers" : "Pokaż numery tygodni",
     "Primary CalDAV address" : "Podstawowy adres CalDAV",
     "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
     "Subscribe" : "Subskrybuj"
