@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
     "Share Calendar" : "Ndani Kalendarin",
     "Shared" : "E ndarë",
+    "Could not save WebCal-calendar" : "Nuk mund të ruhej kalendari-WebCal",
     "WebDAV address for subscriptions" : "Adresa WebDAV për abonimet",
+    "Email sent." : "Email-i u dërgua.",
+    "Could not send your email." : "Nuk mund të dërgohej email-i juaj.",
     "group" : "grup",
     "Details" : "Detajet",
     "Attendees" : "Pjesëmarrës",
@@ -74,11 +77,14 @@ OC.L10N.register(
     "end" : "mbarim",
     "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
     "Week {number} of {year}" : "Java e {number} e {year}",
+    "Successfully imported {imported} objects" : "Objektet u importuan {imported} me sukses",
     "{type} {time} before the event starts" : "{type} {time} para se veprimtaria të fillojë",
     "{type} {time} before the event ends" : "{type} {time} para se veprimtaria të përfundojë",
     "{type} {time} after the event starts" : "{type} {time} pas fillimit të veprimtarisë",
     "{type} {time} after the event ends" : "{type} {time} pas mbarimit të veprimtarisë",
+    "Email at the event's start" : "Email në fillim të ngjarjes",
     "{type} at the event's start" : "{type} në fillim të veprimtarisë",
+    "Email at the event's end" : "Email në fund të ngjarjes",
     "{type} at the event's end" : "{type} në fund të veprimtarisë",
     "{type} at {time}" : "{type} në {time}",
     "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
@@ -135,6 +141,7 @@ OC.L10N.register(
     "Absolute" : "Absolute",
     "Repeat" : "Përsërite",
     "times every" : "herë çdo",
+    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Përkujtuesit e emailit nuk janë implementuar ende në serverin CalDAV, kështu që asnjë nuk do të dërgohet.",
     "Add" : "Shtoje",
     "Email address of attendee" : "Adresa e emailit e pjesmarrësit",
     "Please add your email address in the personal settings in order to add attendees." : "Që të shtoni pjesëmarrës, ju lutemi, shtoni adresën tuaj email te rregullimet personale.",
@@ -158,10 +165,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe që do të integrohet",
     "Publish URL" : "Publiko URL",
     "Settings & import" : "Konfigurimet dhe importi",
-    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
-    "Show week numbers" : "Shfaq numra javësh",
     "Import calendar" : "Importo kalendar",
     "No Calendars selected for import" : "S’ka Kalendarë të përzgjedhur për import",
+    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
+    "Show week numbers" : "Shfaq numra javësh",
     "Primary CalDAV address" : "Adresë CalDAV parësore",
     "iOS/OS X CalDAV address" : "Adresë iOS/OS X CalDAV",
     "Subscribe" : "Abonohu"
