@@ -29,7 +29,10 @@ OC.L10N.register(
     "Some events in this calendar are broken. Please check the JS console for more info." : "Några händelser i kalendern är felaktiga. Vänligen kolla JS-konsolen för mer information.",
     "Share Calendar" : "Dela kalender",
     "Shared" : "Delat",
+    "Could not save WebCal-calendar" : "Kunde inte spara WebCal-kalender",
     "WebDAV address for subscriptions" : "WebDAV-adress för prenumerationer",
+    "Email sent." : "E-post sänt.",
+    "Could not send your email." : "Kunde inte skicka din e-post.",
     "group" : "Grupp",
     "Details" : "Detaljer",
     "Attendees" : "Deltagare",
@@ -74,6 +77,7 @@ OC.L10N.register(
     "end" : "slut",
     "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
     "Week {number} of {year}" : "Vecka {number} år {year}",
+    "Imported {imported} out of {all}, one failure" : "Importerade {imported} av {all}, en misslyckades",
     "Audio alarm {time} before the event starts" : "Ljudalarm {time} före händelsen startar",
     "Email {time} before the event starts" : "Epost {time} före händelsen startar",
     "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
@@ -178,10 +182,10 @@ OC.L10N.register(
     "Iframe to integrate" : "Iframe att integrera",
     "Publish URL" : "Publicera URL",
     "Settings & import" : "Inställningar & import",
-    "Skip simple event editor" : "Använd inte den enkla händelse-redigeraren",
-    "Show week numbers" : "Visa veckonummer",
     "Import calendar" : "Importera kalender",
     "No Calendars selected for import" : "Ingen kalender vald för import",
+    "Skip simple event editor" : "Använd inte den enkla händelse-redigeraren",
+    "Show week numbers" : "Visa veckonummer",
     "Primary CalDAV address" : "Primär CalDAV adress",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adress",
     "Subscribe" : "Prenumerera"
