@@ -26,10 +26,9 @@ OC.L10N.register(
     "Please create a calendar first." : "Xin vui lòng tạo một lịch làm việc trước.",
     "New event" : "Sự kiện mới",
     "CalDAV address for clients" : "Địa chỉ CalDAV cho người dùng đầu cuối",
-    "Error saving WebCal-calendar" : "Lỗi khi lưu WebCal-calendar",
+    "Share Calendar" : "Chia sẻ lịch",
+    "Shared" : "Được chia sẻ",
     "WebDAV address for subscriptions" : "Địa chỉ WebDAV cho các đăng ký",
-    "Email has been sent." : "Thư điện tử đã được gửi.",
-    "There was an issue while sending your email." : "Có một lỗi xảy ra trong khi gửi thư của bạn.",
     "group" : "nhóm",
     "Details" : "Chi tiết",
     "Attendees" : "Người tham gia",
@@ -90,8 +89,6 @@ OC.L10N.register(
     "Week" : "Tuần",
     "Month" : "Tháng",
     "Today" : "Hôm nay",
-    "Share Calendar" : "Chia sẻ lịch",
-    "Shared" : "Được chia sẻ",
     "More" : "hơn",
     "Edit" : "Sửa",
     "Download" : "Tải về",
