@@ -2,7 +2,7 @@
 		<div id="header-left">
 			<a href="<?php print_unescaped(link_to('', 'index.php')); ?>"
 			   title="" id="nextcloud">
-				<div class="logo-icon svg"></div>
+				<div class="logo logo-icon"></div>
 				<h1 class="header-appname">
 					<?php p($theme->getName()); ?>
 				</h1>
